@@ -10,7 +10,7 @@
 #'
 #' @noRd
 get_residuals_splm <- function(betahat, data_object, cholprods_list, hatvalues) {
-  residuals_raw <- as.numeric(do.call("rbind", mapply(
+  residuals_response <- as.numeric(do.call("rbind", mapply(
     y = data_object$y_list, x = data_object$X_list,
     function(y, x) y - x %*% betahat, SIMPLIFY = FALSE
   )))
@@ -19,12 +19,12 @@ get_residuals_splm <- function(betahat, data_object, cholprods_list, hatvalues)
     lapply(cholprods_list, function(x) x$SqrtSigInv_y - x$SqrtSigInv_X %*% betahat)
   ))
   residuals_standardized <- residuals_pearson / sqrt(1 - hatvalues) # (I - H on bottom)
-  list(raw = residuals_raw, pearson = residuals_pearson, standardized = residuals_standardized)
+  list(response = residuals_response, pearson = residuals_pearson, standardized = residuals_standardized)
 }
 
 get_residuals_spautor <- function(betahat, X, y, cholprods, hatvalues) {
-  residuals_raw <- as.numeric(y - X %*% betahat)
+  residuals_response <- as.numeric(y - X %*% betahat)
   residuals_pearson <- as.numeric(cholprods$SqrtSigInv_y - cholprods$SqrtSigInv_X %*% betahat)
   residuals_standardized <- residuals_pearson / sqrt(1 - hatvalues) # (I - H on bottom)
-  list(raw = residuals_raw, pearson = residuals_pearson, standardized = residuals_standardized)
+  list(response = residuals_response, pearson = residuals_pearson, standardized = residuals_standardized)
 }
