@@ -45,7 +45,7 @@ print.splm <- function(x, digits = max(3L, getOption("digits") - 3L),
   if (!x$anisotropy) {
     spcoef <- spcoef[-which(names(spcoef) %in% c("rotate", "scale"))]
   }
-  if (inherits(coef(x, type = "spcov"), "none")) {
+  if (inherits(coef(x, type = "spcov"), c("none", "ie"))) {
     spcoef <- spcoef["ie"]
   }
 
@@ -165,7 +165,7 @@ print.summary.splm <- function(x,
   if (!x$anisotropy) {
     spcoef <- spcoef[-which(names(spcoef) %in% c("rotate", "scale"))]
   }
-  if (inherits(x$coefficients$spcov, "none")) {
+  if (inherits(x$coefficients$spcov, c("none", "ie"))) {
     spcoef <- spcoef["ie"]
   }
 
